@@ -1,6 +1,7 @@
-from azureml.core import Workspace, Experiment, Run
+import os
+import azureml
+from azureml.core import Experiment, Run
 
-from energinetml.backend import default_backend as backend
 from energinetml.core.training import AbstractTrainingContext
 
 from .logger import AzureMlLogger
@@ -8,15 +9,17 @@ from .datasets import DownloadedAzureMLDataStore, MountedAzureMLDataStore
 
 
 class AzureLocalTrainingContext(AbstractTrainingContext):
-    def __init__(self, force_download):
+    def __init__(self, backend, force_download):
         """
+        :param energinetml.azure.AzureBackend backend:
         :param bool force_download:
         """
+        self.backend = backend
         self.force_download = force_download
         self.az_run = None
 
     def train_model(self, model, tags, **kwargs):
-        az_workspace = backend.get_workspace(
+        az_workspace = self.backend.get_workspace(
             name=model.project.workspace_name,
             subscription_id=model.project.subscription_id,
             resource_group=model.project.resource_group,
@@ -29,6 +32,7 @@ class AzureLocalTrainingContext(AbstractTrainingContext):
 
         datasets = DownloadedAzureMLDataStore.from_model(
             model=model,
+            datasets=model.datasets_parsed.local,
             workspace=az_workspace,
             force_download=self.force_download,
         )
@@ -37,10 +41,14 @@ class AzureLocalTrainingContext(AbstractTrainingContext):
             # The "outputs" parameter is provided here with a non-existing
             # folder path to avoid having azureml upload files. We will do
             # this manually somewhere else.
-            self.az_run = az_experiment.start_logging(
-                snapshot_directory=temp_path,
-                outputs='a-folder-that-does-not-exists',
-            )
+            try:
+                self.az_run = az_experiment.start_logging(
+                    snapshot_directory=temp_path,
+                    outputs=os.path.join(temp_path, 'a-folder-that-does-not-exists'),
+                )
+            except azureml._common.exceptions.AzureMLException as e:
+                raise self.backend.parse_azureml_exception(e)
+
             self.az_run.set_tags(tags)
             try:
                 return model.train(
@@ -49,13 +57,34 @@ class AzureLocalTrainingContext(AbstractTrainingContext):
                     **kwargs,
                 )
             finally:
-                self.az_run.complete()
+                try:
+                    self.az_run.complete()
+                except azureml._common.exceptions.AzureMLException as e:
+                    raise self.backend.parse_azureml_exception(e)
 
     def save_output_files(self, model):
-        self.az_run.upload_file('outputs/model.pkl', model.trained_model_path)
+        try:
+            self.az_run.upload_file(
+                'outputs/model.pkl', model.trained_model_path)
+        except azureml._common.exceptions.AzureMLException as e:
+            raise self.backend.parse_azureml_exception(e)
 
     def get_portal_url(self):
-        return self.az_run.get_portal_url()
+        try:
+            return self.az_run.get_portal_url()
+        except azureml._common.exceptions.AzureMLException as e:
+            raise self.backend.parse_azureml_exception(e)
+
+    def get_parameters(self, model):
+        params = {}
+        params.update(model.parameters)
+        params.update(model.parameters_local)
+        return params
+
+    def get_tags(self, model):
+        return {
+            'datasets': ', '.join(model.datasets + model.datasets_local),
+        }
 
 
 class AzureCloudTrainingContext(AbstractTrainingContext):
@@ -68,6 +97,7 @@ class AzureCloudTrainingContext(AbstractTrainingContext):
 
         datasets = MountedAzureMLDataStore.from_model(
             model=model,
+            datasets=model.datasets_parsed.cloud,
             workspace=self.az_run.experiment.workspace,
         )
 
@@ -80,8 +110,16 @@ class AzureCloudTrainingContext(AbstractTrainingContext):
         finally:
             self.az_run.complete()
 
-    def save_output_files(self, model):
-        pass
-
     def get_portal_url(self):
         return self.az_run.get_portal_url()
+
+    def get_parameters(self, model):
+        params = {}
+        params.update(model.parameters)
+        params.update(model.parameters_cloud)
+        return params
+
+    def get_tags(self, model):
+        return {
+            'datasets': ', '.join(model.datasets + model.datasets_cloud),
+        }
