@@ -1,12 +1,13 @@
 import os
+import sys
 import shutil
 import pickle
 import random
 import inspect
 import importlib
 from functools import cached_property
-from typing import Any, List, Dict
 from dataclasses import dataclass, field
+from typing import Any, List, Dict
 
 from energinetml.settings import EMPTY_MODEL_TEMPLATE_DIR
 
@@ -32,8 +33,12 @@ class Model(Configurable):
     compute_target: str
     vm_size: str
     datasets: List[str] = field(default_factory=list)
-    features: List[str] = field(default_factory=list)
+    datasets_local: List[str] = field(default_factory=list)
+    datasets_cloud: List[str] = field(default_factory=list)
     parameters: Dict[str, Any] = field(default_factory=dict)
+    parameters_local: Dict[str, Any] = field(default_factory=dict)
+    parameters_cloud: Dict[str, Any] = field(default_factory=dict)
+    features: List[str] = field(default_factory=list)
     files_include: List[str] = field(default_factory=list)
     files_exclude: List[str] = field(default_factory=list)
 
@@ -73,6 +78,13 @@ class Model(Configurable):
         except Project.NotFound:
             return None
 
+    @cached_property
+    def datasets_parsed(self):
+        """
+        :rtype: ModelDatasets
+        """
+        return ModelDatasets(self)
+
     @property
     def trained_model_path(self):
         """
@@ -100,26 +112,6 @@ class Model(Configurable):
         """
         return self.get_file_path(self.REQUIREMENTS_FILE_NAME)
 
-    @property
-    def datasets_parsed(self):
-        """
-        Parses datasets and returns an iterable of (name, version),
-        where version is optional and can be None.
-
-        Datasets (from self.datasets) must be defined in the format
-        of either "name" or "name:version"
-
-        :rtype: typing.Iterable[typing.Tuple[str, str]]
-        """
-        for dataset in self.datasets:
-            if dataset.count(':') > 1:
-                raise ValueError('Invalid dataset "%s"' % dataset)
-            colon_at = dataset.find(':')
-            if colon_at != -1:
-                yield dataset[:colon_at], dataset[colon_at+1:]
-            else:
-                yield dataset, None
-
     @cached_property
     def requirements(self):
         """
@@ -132,17 +124,6 @@ class Model(Configurable):
         else:
             return RequirementList()
 
-    @property
-    def default_tags(self):
-        """
-        :rtype: typing.Dict[str, typing.Any]
-        """
-        tags = {}
-        if self.datasets:
-            tags['datasets'] = ', '.join(self.datasets)
-        tags.update(self.extra_tags())
-        return tags
-
     @property
     def files(self):
         """
@@ -244,6 +225,55 @@ class Model(Configurable):
         raise NotImplementedError
 
 
+class ModelDatasets(object):
+    """
+    A wrapper for parsing datasets in string-format to specific
+    name and version. Distinguishes between datasets for local
+    and cloud training.
+    """
+    def __init__(self, model):
+        """
+        :param Model model:
+        """
+        self.model = model
+
+    def _parse_datasets(self, datasets):
+        """
+        Parses datasets in the format of either "name" or "name:version"
+        and returns an iterable of (name, version), where version is
+        optional and can be None.
+
+        :param typing.List[str] datasets:
+        :rtype: typing.Iterable[typing.Tuple[str, str]]
+        """
+        for dataset in datasets:
+            if dataset.count(':') > 1:
+                raise ValueError('Invalid dataset "%s"' % dataset)
+            colon_at = dataset.find(':')
+            if colon_at != -1:
+                yield dataset[:colon_at], dataset[colon_at+1:]
+            else:
+                yield dataset, None
+
+    @property
+    def local(self):
+        """
+        :rtype: typing.List[typing.Tuple[str, str]]
+        """
+        all_ = self._parse_datasets(self.model.datasets)
+        local = self._parse_datasets(self.model.datasets_local)
+        return list(all_) + list(local)
+
+    @property
+    def cloud(self):
+        """
+        :rtype: typing.List[typing.Tuple[str, str]]
+        """
+        all_ = self._parse_datasets(self.model.datasets)
+        cloud = self._parse_datasets(self.model.datasets_cloud)
+        return list(all_) + list(cloud)
+
+
 @dataclass
 class TrainedModel(object):
     model: Any = field(default=None)
@@ -388,6 +418,8 @@ def import_model_class(path):
     if not hasattr(module, 'model'):
         raise ModelImportError()
 
+    sys.modules['model'] = module
+
     model_class = getattr(module, 'model')
 
     if not inspect.isclass(model_class):
